@@ -117,7 +117,7 @@ def run():
                                                  options=['Select a model', 'Spheroid', 'Ellipsoid', 'GCS'])
         if geometrical_model != 'Select a model':
             st.session_state.geometrical_model = geometrical_model
-            st.experimental_rerun()
+            st.rerun()
     else:
         st.sidebar.info(f'Geometrical Model: \
                         {st.session_state.geometrical_model}')
@@ -160,7 +160,7 @@ def run():
     # 3D Fitting and Reconstruction
     st.sidebar.markdown('## Imaging menu')
     with st.sidebar.expander('Download Options'):
-        select_imagers_form = st.form(key='select_imagers_form')
+        select_imagers_form = st.form(key='select_imagers_form', border=False)
         imagers_list = select_imagers_form.multiselect('Select Imagers',
                                                        options=selected_imagers.imager_dict.keys(),
                                                        default=['LC2', 'LC3', 'COR2A'],
@@ -168,7 +168,7 @@ def run():
         select_imagers_form.form_submit_button(label='Submit',
                                                on_click=delete_from_state,
                                                kwargs={'vars': ['map', ]})
-        select_timerange_form = st.form(key='select_timerange_form')
+        select_timerange_form = st.form(key='select_timerange_form', border=False)
         imaging_time_range = select_timerange_form.slider('Time Range [hours]',
                                                           min_value=-3., max_value=6.,
                                                           value=[-1., 1.], step=0.5,
@@ -281,10 +281,10 @@ def run():
     fig, axis = make_figure(running_map, image_mode, clim=clim, clip_model=clip_model)
     if st.session_state.plot_mesh_mode == 'Skeleton':
         model.plot(axis, mode='Skeleton')
-    if st.session_state.plot_mesh_mode == 'Full':
+    elif st.session_state.plot_mesh_mode == 'Full':
         model.plot(axis, mode='Skeleton')
         model.plot(axis, mode='Full')
-    if st.session_state.plot_mesh_mode == 'Surface':
+    elif st.session_state.plot_mesh_mode == 'Surface':
         model.plot(axis, only_surface=True)
 
     if star_field:
