@@ -21,7 +21,9 @@
 import datetime
 import io
 import json
+import os
 from copy import copy
+from pathlib import Path
 
 import astropy.units as u
 import matplotlib.colors as colors
@@ -45,6 +47,8 @@ from PyThea.sunpy_dev.map.maputils import (filter_maps,
                                            prepare_maps)
 from PyThea.version import version
 
+database_dir = os.path.join(Path.home(), 'PyThea')
+
 
 def get_hek_flare(day):
     '''
@@ -82,7 +86,7 @@ def make_figure(map, image_mode, clim=[-20, 20], clip_model=True):
     else:
         map.plot(cmap='Greys_r',
                  norm=colors.Normalize(vmin=clim[0], vmax=clim[1]))
-    map.draw_limb()
+    map.draw_limb(resolution=180)
     # map.draw_grid(linewidth=2, color='red') # TODO: This takes too much computation time. Maybe for AIA or EUVI?
     yax = axis.coords[1]
     yax.set_ticklabel(rotation=90)
@@ -124,7 +128,7 @@ def download_fits(date_process, imager, time_range=[-1, 1]):
     result = Fido.search(timerange, *args)
     print(result)
     if result:
-        downloaded_files = Fido.fetch(result)
+        downloaded_files = Fido.fetch(result, path=f'{database_dir}'+'/data/{source}/{instrument}/'+'/{file}')
         try:
             map_ = sunpy.map.Map(downloaded_files)
         except RuntimeError as err:
@@ -296,9 +300,15 @@ def plot_fitting_model(model, fit_args, plt_type='HeightT'):
     elif fit_args['type'] == 'custom':
         title = 'Event: ' + model.event_selected + ' | Funct: ' + fit_args['expression']
 
-    plt.title(title)
-    axis.xaxis.set_major_formatter(mdates.DateFormatter('%Y\n%b-%d\n%H:%M'))
+    axis.set_title(title)
+    locator = mdates.AutoDateLocator(minticks=4, maxticks=8)
+    formatter = mdates.ConciseDateFormatter(locator)
+    axis.xaxis.set_major_locator(locator)
+    axis.xaxis.set_major_formatter(formatter)
     axis.minorticks_on()
+    xlim = axis.get_xlim()
+    if xlim[1] - xlim[0] <= 0.5:
+        axis.xaxis.set_minor_locator(mdates.MinuteLocator(byminute=[0, 10, 20, 30, 40, 50]))
     fig.autofmt_xdate(bottom=0, rotation=0, ha='center')
     plt.legend(loc='lower right')
 
