@@ -4,7 +4,7 @@
 # This is a modified script from sunpy
 try:
     try:
-        from _version import version
+        from PyThea._version import version
     except ImportError:
         from ._version import version
 except Exception:
@@ -17,15 +17,15 @@ except Exception:
     version = '0.0.0'
 
 
-# We use LooseVersion to define major, minor, micro, but ignore any suffixes.
+# We use Version to define major, minor, micro, but ignore any suffixes.
 def split_version(version):
     pieces = [0, 0, 0]
 
     try:
-        from distutils.version import LooseVersion
+        from packaging.version import Version
 
-        for j, piece in enumerate(LooseVersion(version).version[:3]):
-            pieces[j] = int(piece)
+        v = Version(version)
+        pieces = [v.major, v.minor, v.micro]
 
     except Exception:
         pass
